This function calculates the isotope abundances (in %!) and resulting counting statistics error from the raw ion counts. It can be applied to data from both LANS_summary and LANS_maps loading but can be slow if LANS_maps is combined from many analyses.
calculate_abundances(data, ..., name_fun = default_name, quiet = FALSE)the original data frame with the fractional abundance information appended (all fractional abundances are in % and have data_type == "abundance")
a data frame with raw ion counts retrieved from load_LANS_summary
the fractional abundances to calculate, each entry is for one fractional abundance with major isotope first, then
minor isotope, e.g. c(13C, 12C), c(15N12C, 14C12C), ...
the naming function, receives ... from the top level, default concatenates 'F' + minor ion name
whether the function should output information messages or be quiet (default is to output)
Other calculations:
calculate_ratios(),
calculate_sums(),
calculate()