This function calculates the ratios and resulting counting statistics error from the raw ion counts. It can be applied to data from both LANS_summary and LANS_maps loading but can be slow if LANS_maps is combined from many analyses. It can also be applied to ion_sums generate by calculate_sums to calculate elemental ratios (careful, ionization efficiencies skew their scaling!)
calculate_ratios(data, ..., name_fun = default_name, quiet = FALSE)the original data frame with the ratio information appended (all ratios have data_type == "ratio")
a data frame with raw ion counts retrieved from load_LANS_summary
the ratios to calculate, each entry is one ratio with major isotope first, then
minor isotope, e.g. c(13C, 12C), c(15N12C, 14C12C), ...
the naming function, receives ... from the top level, default concatenates column names with '/'
whether the function should output information messages or be quiet (default is to output)
Other calculations:
calculate_abundances(),
calculate_sums(),
calculate()